@@ -78,6 +78,27 @@ is_false <- function(x) {
   identical(x, FALSE)
 }
 
+#' Check if a vector is an integer
+#'
+#' @param x a vector
+#'
+#' @return TRUE of FALSE.
+#' @keywords internal
+is_integer <- function(x, tol = .Machine$double.eps^0.5)
+{
+  all(abs(x - round(x)) < tol)
+}
+
+#' Check if vector is a real (numeric non-integer)
+#'
+#' @param x
+#'
+#' @return A logical.
+#' @keywords internal
+is_real <- function(x, tol = .Machine$double.eps^0.5) {
+  is.numeric(x) && !is_integer(x, tol = )
+}
+
 #' Binary indices
 #'
 #' Wraps around bit_indexr().
